@@ -12,6 +12,7 @@ use proc_exit::WithCodeResultExt;
 use structopt::StructOpt;
 
 mod checks;
+mod color;
 mod config;
 mod git;
 mod report;
@@ -20,7 +21,8 @@ mod report;
 #[structopt(
     setting = structopt::clap::AppSettings::UnifiedHelpMessage,
     setting = structopt::clap::AppSettings::DeriveDisplayOrder,
-    setting = structopt::clap::AppSettings::DontCollapseArgsInUsage
+    setting = structopt::clap::AppSettings::DontCollapseArgsInUsage,
+    setting = concolor_clap::color_choice(),
 )]
 #[structopt(group = structopt::clap::ArgGroup::with_name("mode").multiple(false))]
 struct Options {
@@ -64,6 +66,9 @@ struct Options {
     )]
     format: Format,
 
+    #[structopt(flatten)]
+    color: concolor_clap::Color,
+
     #[structopt(flatten)]
     verbose: clap_verbosity_flag::Verbosity,
 }
@@ -132,10 +137,17 @@ fn load_toml(path: &std::path::Path) -> Result<config::Config, anyhow::Error> {
     toml::from_str(&text).map_err(|e| e.into())
 }
 
-pub fn init_logging(level: Option<log::Level>) {
+fn init_logging(level: Option<log::Level>) {
     if let Some(level) = level {
         let mut builder = env_logger::Builder::new();
 
+        let colored = concolor_control::get(concolor_control::Stream::Stderr).ansi_color();
+        builder.write_style(if colored {
+            env_logger::WriteStyle::Always
+        } else {
+            env_logger::WriteStyle::Never
+        });
+
         builder.filter(None, level.to_level_filter());
 
         if level == log::LevelFilter::Trace {
@@ -158,6 +170,8 @@ pub fn init_logging(level: Option<log::Level>) {
 fn run() -> proc_exit::ExitResult {
     let options = Options::from_args();
 
+    options.color.apply();
+
     init_logging(options.verbose.log_level());
 
     let repo = options
@@ -230,15 +244,21 @@ fn run() -> proc_exit::ExitResult {
     } else if let Some(commits) = options.commits.as_ref() {
         let revspec = git::RevSpec::parse(&repo, commits).with_code(proc_exit::Code::USAGE_ERR)?;
         for commit in revspec.iter() {
+            let abbrev_id = commit.as_object().short_id().ok();
+            let source = abbrev_id
+                .as_ref()
+                .and_then(|id| id.as_str())
+                .map(report::Source::from)
+                .unwrap_or_else(|| commit.id().into());
             if ignore_commit(&commit) {
-                log::trace!("Ignoring {}", commit.id());
+                log::trace!("Ignoring {}", source);
             } else {
-                log::trace!("Processing {}", commit.id());
+                log::trace!("Processing {}", source);
                 let message = commit.message().unwrap();
-                failed |= checks::check_message(commit.id().into(), message, &config, report)
+                failed |= checks::check_message(source, message, &config, report)
                     .with_code(proc_exit::Code::UNKNOWN)?;
                 if !config.merge_commit() {
-                    failed |= checks::check_merge_commit(commit.id().into(), &commit, report)
+                    failed |= checks::check_merge_commit(source, &commit, report)
                         .with_code(proc_exit::Code::UNKNOWN)?;
                 }
             }
@@ -256,15 +276,21 @@ fn run() -> proc_exit::ExitResult {
             .with_code(proc_exit::Code::USAGE_ERR)?
             .peel_to_commit()
             .with_code(proc_exit::Code::USAGE_ERR)?;
+        let abbrev_id = commit.as_object().short_id().ok();
+        let source = abbrev_id
+            .as_ref()
+            .and_then(|id| id.as_str())
+            .map(report::Source::from)
+            .unwrap_or_else(|| commit.id().into());
         if ignore_commit(&commit) {
-            log::trace!("Ignoring {}", commit.id());
+            log::trace!("Ignoring {}", source);
         } else {
-            log::trace!("Processing {}", commit.id());
+            log::trace!("Processing {}", source);
             let message = commit.message().unwrap();
-            failed |= checks::check_message(commit.id().into(), message, &config, report)
+            failed |= checks::check_message(source, message, &config, report)
                 .with_code(proc_exit::Code::UNKNOWN)?;
             if !config.merge_commit() {
-                failed |= checks::check_merge_commit(commit.id().into(), &commit, report)
+                failed |= checks::check_merge_commit(source, &commit, report)
                     .with_code(proc_exit::Code::UNKNOWN)?;
             }
         }
